﻿// (C) Copyright 2010 by Autodesk, Inc. 
//
using System;
using Autodesk.AutoCAD.Runtime;
using Autodesk.AutoCAD.ApplicationServices;
using Autodesk.AutoCAD.DatabaseServices;
using Autodesk.AutoCAD.Geometry;
using Autodesk.AutoCAD.EditorInput;

// This line is not mandatory, but improves loading performances
[assembly: CommandClass(typeof(GTDemo.MyCommands))]

namespace GTDemo
{

    // This class is instantiated by AutoCAD for each document when
    // a command is called by the user the first time in the context
    // of a given document. In other words, non static data in this class
    // is implicitly per-document!
    public class MyCommands
    {
        static Autodesk.AutoCAD.Windows.PaletteSet ps;

        // This is the only command implemented in this application.
        // This command displays a custom AutoCAD .NET Palette that 
        // we will use to interact with the cloud server application.
        [CommandMethod("MyGroup", "_CloudWin", "CloudWin", CommandFlags.Modal)]
        public void MyCommand() // This method can have any name
        {
            if (ps==null)
            {
                // Create a custom palette set that will contain the custom palette.
                // use constructor with Guid so that we can save/load user data
                ps = new Autodesk.AutoCAD.Windows.PaletteSet("Test Palette Set",new Guid("9CE485E7-4B7C-4d62-BD25-2C8D4C741EB4"));
                
                ps.Style = Autodesk.AutoCAD.Windows.PaletteSetStyles.NameEditable | 
                    Autodesk.AutoCAD.Windows.PaletteSetStyles.ShowPropertiesMenu |
                    Autodesk.AutoCAD.Windows.PaletteSetStyles.ShowAutoHideButton | 
                    Autodesk.AutoCAD.Windows.PaletteSetStyles.ShowCloseButton;
                ps.MinimumSize = new System.Drawing.Size(300,300);

                // Add the custom UserControl to the custom palette set
                ps.Add("CloudPalette", new CloudWindow());

            }
            bool b = ps.Visible;
       
            ps.Visible = true;
        }


    }

}
