﻿// (C) Copyright 2010 by Autodesk, Inc. 
//
using System;
using Autodesk.AutoCAD.Runtime;
using Autodesk.AutoCAD.ApplicationServices;
using Autodesk.AutoCAD.DatabaseServices;
using Autodesk.AutoCAD.Geometry;
using Autodesk.AutoCAD.EditorInput;
using System.ServiceModel.Channels;
using System.ServiceModel;
using TaskMonitorServiceWebRole;
using System.DirectoryServices.AccountManagement;
using System.ComponentModel;
using System.Threading;
using Autodesk.AutoCAD.Windows;
using System.Drawing;
using System.DirectoryServices;

// This line is not mandatory, but improves loading performances
[assembly: CommandClass(typeof(TaskMonitorAppAsync.MyCommands))]

namespace TaskMonitorAppAsync
{

    public class MyCommands
    {
        // This is helper class provided with the .NET framework that makes it easy 
        // to create and run background threads
        BackgroundWorker _bw;

        static TrayItem _TrayItem = null;
        static System.Drawing.Icon _Icon;


        public MyCommands()
        {
            // Initialization performed once
            Editor ed = Application.DocumentManager.MdiActiveDocument.Editor;
            sessionId = System.Diagnostics.Process.GetCurrentProcess().Id.ToString();
            
            appName = Application.MainWindow.Text;

            string loginid = System.Environment.UserName;

            string strName=null;

            try
            {
                // Try and get the friendly name of the user automatically. This works when the app
                // has access to the DNS. But fails otherwise
                strName = UserPrincipal.Current.DisplayName;
            }
            catch (System.Exception e)
            {
                // If the friendly name is not accessible, request the user to provide the
                // friendly name manually
                PromptStringOptions prStrOpts = new PromptStringOptions("\nPlease Enter your Full Name:");

                prStrOpts.AllowSpaces = true;

                PromptResult res = ed.GetString(prStrOpts);
                strName = res.StringResult;
            }
            

            if(null != strName)
                strName.Trim();

            if(null != strName && "" != strName)
                userName = strName;
            else
                userName = System.Environment.UserName;


            // Initialize variables for the web service to be used
            Binding binding = new BasicHttpBinding(); 
            EndpointAddress endpointAddress = new EndpointAddress("http://adnmonitor.cloudapp.net/TaskMonitorService.svc?wsdl");

            svrClnt = new TaskMonitorServiceClient(binding, endpointAddress);
        }

        string sessionId;
        string userName;
        string appName;
        TaskMonitorServiceClient svrClnt;

        // Modal Command with pickfirst selection
        [CommandMethod("TrackWorkGroup", "_TrackWorkAsync", "TrackWorkAsync", CommandFlags.Modal | CommandFlags.UsePickSet)]
        public void TrackWorkAsync() // This method can have any name
        {
            // This command registers an event handler that monitors objects added to the drawing
            // database.
            Document doc = Application.DocumentManager.MdiActiveDocument;
            Database db = doc.Database;

            db.ObjectAppended += new ObjectEventHandler(db_ObjectAppended);
        }

        [CommandMethod("TrackWorkGroup", "_SetName", "SetName", CommandFlags.Modal | CommandFlags.UsePickSet)]
        public void GetName() // This method can have any name
        {
            // This is a helper command that can be run to set the friendly name of the user manually
            Editor ed = Application.DocumentManager.MdiActiveDocument.Editor;
            string strName = null;
            
            PromptStringOptions prStrOpts = new PromptStringOptions("\nPlease Enter your Full Name:");

            prStrOpts.AllowSpaces = true;

            PromptResult res = ed.GetString(prStrOpts);
            strName = res.StringResult;

            if (null != strName)
                strName.Trim();

            if (null != strName && "" != strName)
                userName = strName;
        }

        [CommandMethod("TrackWorkGroup", "_ListenToMan", "ListenToMan", CommandFlags.Modal | CommandFlags.UsePickSet)]
        public void ListenToMan() 
        {
            // This command sets up a monitor that looks for "encourage" messages for this user
            
            // Create a custom tray item if it does not exist already
            if(null == _TrayItem)
            {
                System.Reflection.Assembly asm = System.Reflection.Assembly.GetExecutingAssembly();

                Autodesk.AutoCAD.Windows.StatusBar sb = Autodesk.AutoCAD.ApplicationServices.Application.StatusBar;
                _TrayItem = new TrayItem();
                _TrayItem.Visible = true;
                Icon icon = new System.Drawing.Icon(@"C:\OurIcon.ico");

                _TrayItem.Icon = icon;
                _TrayItem.ToolTipText = "copy of TestIcon";
                sb.TrayItems.Add(_TrayItem);

                TrayItemCollection tis = sb.TrayItems;

            }
            if (null == _bw)
            {
                // Launch a background worker and initialize it
                _bw = new BackgroundWorker
                {
                    WorkerReportsProgress = true,
                    WorkerSupportsCancellation = true
                };
                // Set up the background worker to check for messages regularly and report the messages as a bubble in AutoCAD session
                _bw.DoWork += new DoWorkEventHandler(_bw_DoWork);
                _bw.ProgressChanged += new ProgressChangedEventHandler(_bw_ProgressChanged);
                _bw.RunWorkerCompleted += new RunWorkerCompletedEventHandler(_bw_RunWorkerCompleted);
                // This monitoring happens asynchronously so AutoCAD is not blocked when the messages are being checked
                _bw.RunWorkerAsync("Message to worker");

            }
        }

        [CommandMethod("TrackWorkGroup", "_IgnoreTheMan", "IgnoreTheMan", CommandFlags.Modal | CommandFlags.UsePickSet)]
        public void IgnoreTheMan() // This method can have any name
        {
            // Unregister the "encourage" message monitor
            if (null != _bw)
            {
                _bw.DoWork -= new DoWorkEventHandler(_bw_DoWork);
                _bw.ProgressChanged -= new ProgressChangedEventHandler(_bw_ProgressChanged);
                _bw.RunWorkerCompleted -= new RunWorkerCompletedEventHandler(_bw_RunWorkerCompleted);
                _bw = null;
            }
        }

        void _bw_RunWorkerCompleted(object sender, RunWorkerCompletedEventArgs e)
        {
            System.Exception exp = e.Error;
        }

        void _bw_ProgressChanged(object sender, ProgressChangedEventArgs e)
        {
            // If the encourage message is found, display it as a bubble
            if ("Nothing" == (string)e.UserState)
                return;
            TrayItemBubbleWindow bubbleWindow = new TrayItemBubbleWindow();
            bubbleWindow.Text = (string)e.UserState;
            bubbleWindow.IconType = IconType.Information;
            bubbleWindow.Title = "The Manager has spoken!";
            
            if(Application.StatusBar.TrayItems.Count > 0)
            {
                _TrayItem.ShowBubbleWindow(bubbleWindow);

            }
        }

        void _bw_DoWork(object sender, DoWorkEventArgs e)
        {
 
            // This is where the cloud service is polled regularly for "encourage" messages
            int counter = 0;
            
            while (true)
            {
                String str = svrClnt.GetEncouragement(userName);
                _bw.ReportProgress(10, str);
                Thread.Sleep(5000);
                counter += 10;
            }
        }

        [CommandMethod("TrackWorkGroup", "_UnregTrackAsync", "UnregTrackAsync", CommandFlags.Modal)]
        public void UnregTrackAsync()
        {
            // Do not update the cloud database with the entities added info
            Document doc = Application.DocumentManager.MdiActiveDocument;
            Database db = doc.Database;

            db.ObjectAppended -= new ObjectEventHandler(db_ObjectAppended);

        }

        void db_ObjectAppended(object sender, ObjectEventArgs e)
        {
            // Asynchronously update the cloud database with the entities added information
            WorkInformation wrkInfo = new WorkInformation();

            wrkInfo.sessionId = sessionId;
            wrkInfo.name = userName;
            wrkInfo.dateTime = DateTime.Now;
            wrkInfo.appname = appName;
            wrkInfo.entityName = e.DBObject.GetType().ToString();
            wrkInfo.numEntities = 1;

            //svrClnt.AddWorkInformation(wrkInfo); // Calling this method updates the cloud DB
                                                   // Synchronously
            svrClnt.BeginAddWorkInformation(wrkInfo, Responder, wrkInfo); // Update DB Asynchronously

        }

        void Responder(IAsyncResult result)
        {
            svrClnt.EndAddWorkInformation(result);
        }

    }

}
